//
// Copyright(C) Sergey A. Galin, 2008. http://sageshome.net/
//
// This program is distributed under terms of GNU General Public License,
// version 2 or higher, published by Free Software Foundation, at your option.
// See COPYING.txt for more information.
//
//-----------------------------------------------------------------------------
// RIFF file format definition
//-----------------------------------------------------------------------------

#include <stdio.h>
#include "riff.h"

const struct TRIFFWavHeader kDefaultRIFF = {
	MAKEFOURCC('R', 'I', 'F', 'F'),
	0,
	MAKEFOURCC('W', 'A', 'V', 'E'),
	MAKEFOURCC('f', 'm', 't', ' '),
	0x10,
	1,
	2,
	44100,
	44100*4,
	0,
	16,
	MAKEFOURCC('d', 'a', 't', 'a'),
	0
};	


void TRIFFWavHeader::Init()
{
	(*this) = kDefaultRIFF;
}

bool TRIFFWavHeader::VerifySignatures()
{
	bool ret =
		riffheader	== kDefaultRIFF.riffheader	&&
		WAVEsig		== kDefaultRIFF.WAVEsig		&&
		fmtsig		== kDefaultRIFF.fmtsig		&&
		dataheader	== kDefaultRIFF.dataheader;
	if(!ret)
		printf("Info: Signature verification failed.\n");
	return ret;
}

bool TRIFFWavHeader::IsValidPCMWav()
{
	return 
		VerifySignatures() &&
		fmtlen == 0x10 &&
		FormatTag == 1 &&
		(Channels == 1 || Channels == 2)
		 &&
		(SamplesPerSec*Channels*BitsPerSample/8)==AvgBytesPerSec;
}

const TRIFFWavHeader* TRIFFWavHeader::GetDefaultHeader()
{	
	return &kDefaultRIFF;
}





